@@ -2,7 +2,8 @@
 library("SPUTNIK")
 
 ## Mass spectrometry intensity matrix
-X <- matrix(rnorm(200), 20, 40)
+X <- matrix(rnorm(16000), 400, 40)
+X[X < 0] <- 0
 
 ## Print original dimensions
 print(dim(X))
@@ -11,15 +12,17 @@ print(dim(X))
 mzVector <- seq(600, 900, by = (900 - 600) / 39)
 
 ## Read the image size
-imSize <- c(5, 4)
+imSize <- c(20, 20)
 
 ## Construct the ms.dataset object
 msiX <- msiDataset(X, mzVector, imSize[1], imSize[2])
 
 ## Calculate the p-values using the Clark Evans test, then apply Benjamini-
 ## Hochberg correction.
-csr <- CSRPeaksFilter(msiData = msiX, method = "ClarkEvans",
-                      calculateCovariate = FALSE, adjMethod = "BH")
+csr <- CSRPeaksFilter(
+  msiData = msiX, method = "ClarkEvans",
+  calculateCovariate = FALSE, adjMethod = "BH"
+)
 
 ## Print selected peaks
 print(csr$q.value)
